django_analyses.views package — django_analyses 0.0.3 documentation

# django_analyses.views package

## Submodules

## django_analyses.views.analysis module

class `django_analyses.views.analysis.` `AnalysisViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.analysis.AnalysisFilter`

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.analysis.AnalysisSerializer`

  `suffix` = None

## django_analyses.views.analysis_version module

class `django_analyses.views.analysis_version.` `AnalysisVersionViewSet`(**kwargs)

  Bases: `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `name` = None
  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.analysis_version.AnalysisVersionSerializer`

  `suffix` = None

## django_analyses.views.category module

class `django_analyses.views.category.` `CategoryViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.category.CategoryFilter`

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.category.CategorySerializer`

  `suffix` = None

## django_analyses.views.defaults module

class `django_analyses.views.defaults.` `DefaultsMixin`

  Bases: `object`

  Default settings for view authentication, permissions, filtering and pagination.

  `authentication_classes` = (<class 'rest_framework.authentication.BasicAuthentication'>, <class 'rest_framework.authentication.TokenAuthentication'>)
  `filter_backends` = (<class 'django_filters.rest_framework.backends.DjangoFilterBackend'>, <class 'rest_framework.filters.SearchFilter'>, <class 'rest_framework.filters.OrderingFilter'>)
  `permission_classes` = (<class 'rest_framework.permissions.IsAuthenticated'>,)

## django_analyses.views.input module

class `django_analyses.views.input.` `InputViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.input.input.InputFilter`

  `get_queryset`()

    Get the list of items for this view. This must be an iterable, and may be a queryset. Defaults to using self.queryset.

    This method should always be used rather than accessing self.queryset directly, as self.queryset gets evaluated only once, and those results are cached for all subsequent requests.

    You may want to override this if you need to provide different querysets depending on the incoming request.

    (Eg. return a list of items that is specific to the user)

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `serializer_class`

    alias of `django_analyses.serializers.input.input.InputSerializer`

  `suffix` = None

## django_analyses.views.input_definition module

class `django_analyses.views.input_definition.` `InputDefinitionViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.input.input_definition.InputDefinitionFilter`

  `get_queryset`()

    Get the list of items for this view. This must be an iterable, and may be a queryset. Defaults to using self.queryset.

    This method should always be used rather than accessing self.queryset directly, as self.queryset gets evaluated only once, and those results are cached for all subsequent requests.

    You may want to override this if you need to provide different querysets depending on the incoming request.

    (Eg. return a list of items that is specific to the user)

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `serializer_class`

    alias of `django_analyses.serializers.input.definitions.input_definition.InputDefinitionSerializer`

  `suffix` = None

## django_analyses.views.input_specification module

class `django_analyses.views.input_specification.` `InputSpecificationViewSet`(**kwargs)

  Bases: `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `name` = None
  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.input.input_specification.InputSpecificationSerializer`

  `suffix` = None

## django_analyses.views.node module

class `django_analyses.views.node.` `NodeViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.pipeline.node.NodeFilter`

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.pipeline.node.NodeSerializer`

  `suffix` = None

## django_analyses.views.output module

class `django_analyses.views.output.` `OutputViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.output.output.OutputFilter`

  `get_queryset`()

    Get the list of items for this view. This must be an iterable, and may be a queryset. Defaults to using self.queryset.

    This method should always be used rather than accessing self.queryset directly, as self.queryset gets evaluated only once, and those results are cached for all subsequent requests.

    You may want to override this if you need to provide different querysets depending on the incoming request.

    (Eg. return a list of items that is specific to the user)

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `serializer_class`

    alias of `django_analyses.serializers.output.output.OutputSerializer`

  `suffix` = None

## django_analyses.views.output_definition module

class `django_analyses.views.output_definition.` `OutputDefinitionViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.output.output_definition.OutputDefinitionFilter`

  `get_queryset`()

    Get the list of items for this view. This must be an iterable, and may be a queryset. Defaults to using self.queryset.

    This method should always be used rather than accessing self.queryset directly, as self.queryset gets evaluated only once, and those results are cached for all subsequent requests.

    You may want to override this if you need to provide different querysets depending on the incoming request.

    (Eg. return a list of items that is specific to the user)

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `serializer_class`

    alias of `django_analyses.serializers.output.definitions.output_definition.OutputDefinitionSerializer`

  `suffix` = None

## django_analyses.views.output_specification module

class `django_analyses.views.output_specification.` `OutputSpecificationViewSet`(**kwargs)

  Bases: `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `name` = None
  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.output.output_specification.OutputSpecificationSerializer`

  `suffix` = None

## django_analyses.views.pagination module

class `django_analyses.views.pagination.` `StandardResultsSetPagination`

  Bases: `rest_framework.pagination.PageNumberPagination`

  Default pagination parameters. This didn’t work as part of the DefaultsMixin and therefore has to be defined separately in the ‘pagination_class’ configuration.

  `page_size` = 100
  `page_size_query_param` = 'page_size'

## django_analyses.views.pipe module

class `django_analyses.views.pipe.` `PipeViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.pipeline.pipe.PipeFilter`

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.pipeline.pipe.PipeSerializer`

  `suffix` = None

## django_analyses.views.pipeline module

class `django_analyses.views.pipeline.` `PipelineViewSet`(**kwargs)

  Bases: `django_analyses.views.defaults.DefaultsMixin`, `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `filter_class`

    alias of `django_analyses.filters.pipeline.pipeline.PipelineFilter`

  `name` = None
  `pagination_class`

    alias of `django_analyses.views.pagination.StandardResultsSetPagination`

  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.pipeline.pipeline.PipelineSerializer`

  `suffix` = None

## django_analyses.views.run module

class `django_analyses.views.run.` `RunViewSet`(**kwargs)

  Bases: `rest_framework.viewsets.ModelViewSet`

  `basename` = None
  `description` = None
  `detail` = None
  `name` = None
  `queryset`
  `serializer_class`

    alias of `django_analyses.serializers.run.RunSerializer`

  `suffix` = None

## Module contents